@@ -1,10 +1,11 @@
-# $Id: /mirror/gungho/lib/Gungho/Provider.pm 6457 2007-04-11T03:32:16.482599Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Provider.pm 4037 2007-10-25T14:20:48.994833Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
 
 package Gungho::Provider;
 use strict;
+use warnings;
 use base qw(Gungho::Base);
 use Gungho::Request;
 
@@ -15,20 +16,13 @@ sub dispatch {}
 sub dispatch_request
 {
     my ($self, $c, $req) = @_;
-    eval {
-        $c->send_request($req);
-    };
-    if (my $e = $@) {
-        if ($e->isa('Gungho::Exception::RequestThrottled')) {
-            # This request was throttled. Attempt to do it later
-            $self->pushback_request($req);
-        } else {
-            die $e;
-        }
-    }
+    $c->send_request($req);
 }
 
-sub pushback_request {}
+sub pushback_request {
+    my ($self, $c, $req) = @_;
+    $self->add_request($req);
+}
 
 1;
 
@@ -52,7 +46,7 @@ Dispatch requests to be fetched to the Gungho framework
 
 Dispatch a single request
 
-=head2 pushback_request($req)
+=head2 pushback_request($c, $req)
 
 Push back a request which couldn't be sent to the engine, for example
 because the request was throttled.
